@@ -588,6 +588,8 @@ public class AudioPlayer implements Runnable {
                 }
                 try {
                     waitFor.join();
+//                    System.gc(); //***TEST***
+//                    Thread.sleep(5000); //***TEST***
                 }
                 catch(InterruptedException ex) {
                     
@@ -600,6 +602,15 @@ public class AudioPlayer implements Runnable {
             state = 'P';
             if (fullAnnouncement.length()>0) {
                 try {
+                    String strWaitIime = Jampal.initialProperties.getProperty("announce-wait","0");
+                    int waitTime = 0;
+                    try {
+                        waitTime = Integer.parseInt(strWaitIime);
+                    }
+                    catch(Exception ex) {
+                        waitTime = 0;
+                    }
+                    Thread.sleep(waitTime);
                     announce = new Announce(fullAnnouncement.toString());
                     announce.start();
                     if (!mainFrame.continuousMenuItem.isSelected()&&state=='P')
@@ -902,7 +913,7 @@ public class AudioPlayer implements Runnable {
         public void run() {
             // sleep 2 secs in case the next song wants the line
             try {
-                Thread.sleep(2000);
+                Thread.sleep(2000); //2000 
             }
             catch (InterruptedException ex) {
                 
@@ -955,10 +966,10 @@ public class AudioPlayer implements Runnable {
                             newVoice = voiceSettings[1];
                         }
                     }
-//                    if (newEngine == null) {
-//                        newEngine = Jampal.initialProperties.getProperty("speech-engine");
-//                        newVoice = Jampal.initialProperties.getProperty("voice");
-//                    }
+                    if (newEngine == null) {
+                        newEngine = Jampal.initialProperties.getProperty("default-speech-engine");
+                        newVoice = "";
+                    }
                     if (newVoice.length() == 0 && "eSpeak".equals(newEngine)) {
                         if (announcementLanguage.length() == 3) {
                             newVoice = mainFrame.library.attributes.shortLangMap.get(announcementLanguage);
